Stoq API reference
==================

Contents:

.. toctree::
   :maxdepth: 1

   stoq - stoq toplevel module <stoq>
   stoq.gui - applications <stoq.gui>
   stoq.lib - misc <stoq.lib>
   stoqlib - stoqlib toplevel module <stoqlib>
   stoqlib.database - database <stoqlib.database>
   stoqlib.domain - domain classes <stoqlib.domain>
   stoqlib.drivers - drivers <stoqlib.drivers>
   stoqlib.exporters - data exporters <stoqlib.exporters>
   stoqlib.gui - Gtk/GNOME ui <stoqlib.gui>
   stoqlib.importers - data importers <stoqlib.importers>
   stoqlib.l10n - Localization <stoqlib.l10n>
   stoqlib.lib - Misc library modules <stoqlib.lib>
   stoqlib.net - Networking <stoqlib.net>
   stoqlib.reporting - Report generation <stoqlib.reporting>
   stoqlib.test - Unittests <stoqlib.test>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

